@@ -73,14 +73,13 @@ fmp_get <- function(
   resource,
   symbol = NULL,
   params = list(),
-  api_version = "v3",
+  api_version = "stable",
   snake_case = TRUE
 ) {
-  if (!is.null(symbol)) {
-    validate_symbol(symbol)
-    resource_processed <- paste0(resource, "/", symbol)
-  } else {
-    resource_processed <- resource
+  resource_processed <- build_resource(resource, symbol, api_version)
+
+  if (api_version == "stable" && !is.null(symbol)) {
+    params$symbol <- symbol
   }
 
   if (!is.null(params$limit)) {
@@ -109,6 +108,22 @@ fmp_get <- function(
   data_processed
 }
 
+#' @keywords internal
+#' @noRd
+build_resource <- function(resource, symbol, api_version) {
+  if (!is.null(symbol)) {
+    validate_symbol(symbol)
+    if (api_version == "stable") {
+      resource_processed <- resource
+    } else {
+      resource_processed <- paste0(resource, "/", symbol)
+    }
+  } else {
+    resource_processed <- resource
+  }
+  resource_processed
+}
+
 #' Perform a request to the Financial Modeling Prep API
 #'
 #' This function sends a request to the Financial Modeling Prep (FMP) API based
@@ -121,7 +136,7 @@ fmp_get <- function(
 #' @param params Additional query parameters to be included in the API request.
 #' @param base_url The base URL for the FMP API. Defaults to
 #' "https://financialmodelingprep.com/api/".
-#' @param api_version The version of the FMP API to use. Defaults to "v3".
+#' @param api_version The version of the FMP API to use. Defaults to "stable".
 #'
 #' @return A parsed JSON response from the FMP API.
 #'
@@ -130,9 +145,11 @@ fmp_get <- function(
 perform_request <- function(
   resource,
   params,
-  base_url = "https://financialmodelingprep.com/api/",
-  api_version = "v3"
+  base_url = "https://financialmodelingprep.com/",
+  api_version = "stable"
 ) {
+  base_url <- build_base_url(base_url, api_version)
+
   req <- create_request(base_url, api_version, resource, params)
 
   resp <- req |>
@@ -151,6 +168,15 @@ perform_request <- function(
   }
 }
 
+#' @keywords internal
+#' @noRd
+build_base_url <- function(base_url, api_version) {
+  if (api_version %in% c("v1", "v2", "v3")) {
+    base_url <- paste0(base_url, "api/")
+  }
+  base_url
+}
+
 #' @keywords internal
 #' @noRd
 create_request <- function(base_url, api_version, resource, params) {
